Crate kcr_trust_cert_manager_io

Crate kcr_trust_cert_manager_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the trust.cert-manager.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

trust.cert-manager.io/v1alpha1

  • Bundle

Modules

v1alpha1